package javax.net.ssl;

import java.security.NoSuchAlgorithmException;
import javax.net.ServerSocketFactory;

public abstract class SSLServerSocketFactory extends ServerSocketFactory
{
    private static SSLServerSocketFactory theFactory;
    private static boolean propertyChecked;
    
    private static void log(String x) {
        if (SSLSocketFactory.DEBUG) {
            System.out.println(x);
        }
    }
    
    protected SSLServerSocketFactory() {
    }
    
    public static synchronized ServerSocketFactory getDefault() {
        if (SSLServerSocketFactory.theFactory != null) {
            return SSLServerSocketFactory.theFactory;
        }
        if (!SSLServerSocketFactory.propertyChecked) {
            SSLServerSocketFactory.propertyChecked = true;
            String securityProperty = SSLSocketFactory.getSecurityProperty("ssl.ServerSocketFactory.provider");
            if (securityProperty != null) {
                log("setting up default SSLServerSocketFactory");
                try {
                    Class<Object> clazz = null;
                    try {
                        clazz = Class.forName(securityProperty);
                    }
                    catch (ClassNotFoundException ex) {
                        ClassLoader systemClassLoader = ClassLoader.getSystemClassLoader();
                        if (systemClassLoader != null) {
                            clazz = systemClassLoader.loadClass(securityProperty);
                        }
                    }
                    log("class " + securityProperty + " is loaded");
                    SSLServerSocketFactory theFactory = (SSLServerSocketFactory)clazz.newInstance();
                    log("instantiated an instance of class " + securityProperty);
                    return SSLServerSocketFactory.theFactory = theFactory;
                }
                catch (Exception obj) {
                    log("SSLServerSocketFactory instantiation failed: " + obj);
                    return SSLServerSocketFactory.theFactory = new DefaultSSLServerSocketFactory(obj);
                }
            }
        }
        try {
            return SSLContext.getDefault().getServerSocketFactory();
        }
        catch (NoSuchAlgorithmException ex2) {
            return new DefaultSSLServerSocketFactory(ex2);
        }
    }
    
    public abstract String[] getDefaultCipherSuites();
    
    public abstract String[] getSupportedCipherSuites();
}
